From ed055bf5d9222546143fa212b578be273ace2269 Mon Sep 17 00:00:00 2001
From: David Geissbuhler <david.geissbuhler@idiap.ch>
Date: Tue, 26 Sep 2017 14:42:22 +0200
Subject: [PATCH] Fixed documentation

---
 bob/pad/face/config/database/mifs.py | 6 +++---
 bob/pad/face/config/mifs.py          | 2 +-
 bob/pad/face/database/mifs.py        | 6 ++----
 3 files changed, 6 insertions(+), 8 deletions(-)

diff --git a/bob/pad/face/config/mifs.py b/bob/pad/face/config/mifs.py
index 140558e4..5209463b 100644
--- a/bob/pad/face/config/mifs.py
+++ b/bob/pad/face/config/mifs.py
@@ -27,7 +27,7 @@ database settings
    manner, respecting usage protocols. It does **not** contain the raw
    data files. You should procure those yourself.
 
-Notice that ``original_directory`` is set to ``[YOUR_REPLAY_ATTACK_DIRECTORY]``.
+Notice that ``original_directory`` is set to ``[YOUR_MIFS_DATABASE_DIRECTORY]``.
 You must make sure to create ``${HOME}/.bob_bio_databases.txt`` setting this
 value to the place where you actually installed the Replayattack Database, as
 explained in the section :ref:`bob.pad.face.baselines`.
diff --git a/bob/pad/face/database/mifs.py b/bob/pad/face/database/mifs.py
index a9cc367e..8f96ee40 100644
--- a/bob/pad/face/database/mifs.py
+++ b/bob/pad/face/database/mifs.py
@@ -78,8 +78,8 @@ class MIFSPadDatabase(FileListPadDatabase):
     def annotations(self, f):
         """
         Return annotations for a given file object ``f``, which is an instance
-        of ``ReplayPadFile`` defined in the HLDI of the Replay-Attack DB.
-        The ``load()`` method of ``ReplayPadFile`` class (see above)
+        of ``MIFSPadFile`` defined in the HLDI of the MIFS DB.
+        The ``load()`` method of ``MIFSPadFile`` class (see above)
         returns a video, therefore this method returns bounding-box annotations
         for each video frame. The annotations are returned as dictionary of dictionaries.
 
@@ -106,8 +106,6 @@ class MIFSPadDatabase(FileListPadDatabase):
 
         topleft = (bbox[0], bbox[1])
         bottomright = (bbox[0] + bbox[2], bbox[1] + bbox[3])
-        #topleft = (bbox[1], bbox[0])
-        #bottomright = (bbox[1] + bbox[3], bbox[0] + bbox[2])
 
         annotations['0'] = {'topleft': topleft, 'bottomright': bottomright}
 
diff --git a/bob/pad/face/config/database/mifs.py b/bob/pad/face/config/database/mifs.py
index c262f880..b70b3105 100644
--- a/bob/pad/face/config/database/mifs.py
+++ b/bob/pad/face/config/database/mifs.py
@@ -17,7 +17,7 @@ database = MIFSPadDatabase(
     original_extension=original_extension,
     training_depends_on_protocol=True,
 )
 """The :py:class:`bob.pad.base.database.PadDatabase` derivative with Replay-Mobile
 database settings.
 
 .. warning::
@@ -26,8 +26,8 @@ database settings.
    manner, respecting usage protocols. It does **not** contain the raw
    data files. You should procure those yourself.
 
-Notice that ``original_directory`` is set to ``[YOUR_REPLAY_MOBILE_DIRECTORY]``.
+Notice that ``original_directory`` is set to ``[YOUR_MIFS_DATABASE_DIRECTORY]``.
 You must make sure to create ``${HOME}/.bob_bio_databases.txt`` setting this
-value to the place where you actually installed the Replay-Mobile Database, as
+value to the place where you actually installed the MIFS Database, as
 explained in the section :ref:`bob.pad.face.baselines`.
 """
@@ -17,7 +17,7 @@ database = MIFSPadDatabase(
     training_depends_on_protocol=True,
 )
-"""The :py:class:`bob.pad.base.database.PadDatabase` derivative with Replay-Mobile
+"""The :py:class:`bob.pad.base.database.PadDatabase` derivative with MIFS
 database settings.
 
-- 
GitLab